@@ -11,7 +11,7 @@ use constant DEBUG        => $ENV{MOJO_IRC_DEBUG}     || 0;
 use constant DEFAULT_CERT => $ENV{MOJO_IRC_CERT_FILE} || catfile dirname(__FILE__), 'mojo-irc-client.crt';
 use constant DEFAULT_KEY  => $ENV{MOJO_IRC_KEY_FILE}  || catfile dirname(__FILE__), 'mojo-irc-client.key';
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 my %CTCP_QUOTE = ("\012" => 'n', "\015" => 'r', "\0" => '0', "\cP" => "\cP");
 
@@ -20,16 +20,17 @@ my @DEFAULT_EVENTS = qw(
   ctcp_ping ctcp_time ctcp_version
 );
 
-has ioloop => sub { Mojo::IOLoop->singleton };
-has local_address => '';
-has name          => 'Mojo IRC';
-has nick          => sub { shift->_build_nick };
-has parser        => sub { Parse::IRC->new; };
-has pass          => '';
-has real_host     => '';
-has track_any     => 0;
-has tls           => undef;
-has user          => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
+has connect_timeout => sub { $ENV{MOJO_IRC_CONNECT_TIMEOUT} || 30 };
+has ioloop          => sub { Mojo::IOLoop->singleton };
+has local_address   => '';
+has name            => 'Mojo IRC';
+has nick   => sub { shift->_build_nick };
+has parser => sub { Parse::IRC->new; };
+has pass   => '';
+has real_host => '';
+has track_any => 0;
+has tls       => undef;
+has user      => sub { $ENV{USER} || getlogin || getpwuid($<) || 'anonymous' };
 
 sub server {
   my ($self, $server) = @_;
@@ -81,6 +82,7 @@ sub connect {
   $self->{stream_id} = $self->ioloop->client(
     address => $host,
     port    => $port,
+    timeout => $self->connect_timeout,
     @extra,
     sub {
       my ($loop, $err, $stream) = @_;
@@ -313,7 +315,7 @@ Mojo::IRC - IRC Client for the Mojo IOLoop
 
 =head1 VERSION
 
-0.33
+0.34
 
 =head1 SYNOPSIS
 
@@ -403,6 +405,15 @@ See L<Mojo::IRC::Events> for sample events.
 
 =head1 ATTRIBUTES
 
+=head2 connect_timeout
+
+  $int = $self->connect_timeout;
+  $self = $self->connect_timeout(60);
+
+Maximum amount of time in seconds establishing a connection may take before
+getting canceled, defaults to the value of the C<MOJO_IRC_CONNECT_TIMEOUT>
+environment variable or 30.
+
 =head2 ioloop
 
 Holds an instance of L<Mojo::IOLoop>.
